###########################
Keithley 2182 Nanovoltmeter
###########################

.. autoclass:: pymeasure.instruments.keithley.Keithley2182
    :members:
    :show-inheritance:
    :inherited-members: CommonBase

.. autoclass:: pymeasure.instruments.keithley.keithley2182.Keithley2182Channel
    :members:
    :show-inheritance: